StorageRef class

Constructors

StorageRef.withReference(dynamic reference)

Properties

bucket → String
no setter
fullPath → String
no setter
hashCode → int
The hash code for this object.
no setterinherited
name → String
no setter
parent → StorageRef
no setter
root → StorageRef
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

child(String ref) → StorageRef
delete() → Future<void>
deleteFiles() → Future<void>
downloadFile() → Future<DownloadTaskForAll>
getData([int maxSize = 10485760]) → Future<Uint8List?>
getDirectories() → Future<List<StorageDirectory>>
getDirSize() → Future<int>
getDownloadURL() → Future<String>
getFiles() → Future<List<StorageFile>>
getMetadata() → Future<FullMetadataForAll>
getSize() → Future<int>
listAll() → Future<ListResultForAll>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
putData(Uint8List data, [SettableMetadata? metadata]) → UploadTaskForAll
putFile(File file, [SettableMetadata? metadata]) → UploadTaskForAll
putString(String data, {PutStringFormat format = PutStringFormat.raw, SettableMetadata? metadata}) → UploadTaskForAll
scan() → Future<List<StorageFile>>
toString() → String
A string representation of this object.
override
writeToFile(File file) → Future<DownloadTaskForAll>

Operators

operator ==(Object other) → bool
The equality operator.
inherited